/* rmmod.c: remove a module from the kernel.
    Copyright (C) 2001  Rusty Russell.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <asm/unistd.h>

static void print_usage(const char *progname)
{
	fprintf(stderr,
		"Usage: %s <modulename>\n", progname);
	exit(1);
}

int main(int argc, char *argv[])
{
	long int ret;
	char *name, *ext;

	if (!argv[1])
		print_usage(argv[0]);

	/* Strip path and .o off filename to give name */
	name = strrchr(argv[1], '/');
	if (!name) name = argv[1];
	else name++;
	ext = strrchr(name, '.');
	if (ext) *ext = '\0';

	ret = syscall(__NR_delete_module, name);
	if (ret != 0) {
		fprintf(stderr, "Error removing `%s': %s\n",
			name, strerror(errno));
		exit(1);
	}
	exit(0);
}
